@@ -1,4 +1,4 @@
-def user(app):
+def replit_auth(app):
   @app.before_request
   def load_user():
     from flask import request
